@@ -1,4 +1,5 @@
 #![allow(clippy::integer_arithmetic)]
+mod cluster_tpu_info;
 pub mod max_slots;
 pub mod optimistically_confirmed_bank_tracker;
 pub mod parsed_token_accounts;
@@ -10,7 +11,7 @@ pub mod rpc_pubsub_service;
 pub mod rpc_service;
 pub mod rpc_subscription_tracker;
 pub mod rpc_subscriptions;
-pub mod send_transaction_service;
+pub mod transaction_notifier_interface;
 pub mod transaction_status_service;
 
 #[macro_use]
